@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: DownloadFlowController.h 2290 2006-12-22 13:41:02Z svn $
+ * $Id: DownloadFlowController.h 2313 2006-12-24 22:56:51Z svn $
  *****************************************************************************/
 
 #ifndef DOWNLOAD_FLOW_CONTROLLER_H
@@ -49,8 +49,8 @@ class DownloadFlowController: public FlowController
 {
 public:
     DownloadFlowController();
-    bool add_session(apr_sockaddr_t *ip_address);
-    void remove_session(apr_sockaddr_t *ip_address);
+    bool add_session(apr_sockaddr_t *sockaddr);
+    void remove_session(apr_sockaddr_t *sockaddr);
 
     static DownloadFlowController *get_instance(apr_shm_t *shm);
     static apr_size_t get_memory_size();
@@ -60,13 +60,12 @@ public:
 
 private:
     typedef struct Downloader {
-        apr_size_t ip_address_size;
-        apr_uint32_t ip_address[sizeof(address_type)/sizeof(apr_uint32_t)];
+        char paddress[MAX_PADDRESS_SIZE]; // パスカル文字列
         apr_size_t session_count;
     } downloader_t;
 
-    bool downloader_list_add(apr_sockaddr_t *ip_address);
-    downloader_t *downloader_list_get(apr_sockaddr_t *ip_address);
+    bool downloader_list_add(apr_sockaddr_t *sockaddr);
+    downloader_t *downloader_list_get(apr_sockaddr_t *sockaddr);
 
     static const char *dump_downloader(apr_pool_t *pool,
                                        downloader_t *downloader);
