@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: TemplateExecutor.h 2035 2006-11-23 16:14:21Z svn $
+ * $Id: TemplateExecutor.h 2296 2006-12-24 02:58:57Z svn $
  *****************************************************************************/
 
 #ifndef TEMPLATE_EXECUTOR_H
@@ -85,9 +85,9 @@ private:
     variable_t *create_variable();
     scalar_t *create_scalar();
 
-    void print(const char *str, apr_size_t length) throw();
-    void print(const char *str) throw();
-    void print(int i) throw();
+    void print(const char *str, apr_size_t length);
+    void print(const char *str);
+    void print(int i);
 
     apr_pool_t *pool_;
     ResponseWriterClass writer_;
