@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: ThumbnailVariableCreator.cpp 2185 2006-12-08 17:25:48Z svn $
+ * $Id: ThumbnailVariableCreator.cpp 2297 2006-12-24 03:13:15Z svn $
  *****************************************************************************/
 
 #include "Environment.h"
@@ -33,7 +33,7 @@
 #include "Macro.h"
 #include "SourceInfo.h"
 
-SOURCE_INFO_ADD("$Id: ThumbnailVariableCreator.cpp 2185 2006-12-08 17:25:48Z svn $");
+SOURCE_INFO_ADD("$Id: ThumbnailVariableCreator.cpp 2297 2006-12-24 03:13:15Z svn $");
 
 /******************************************************************************
  * public メソッド
@@ -104,7 +104,7 @@ inline TemplateVariable::variable_t *
 ThumbnailVariableCreator::create_thumbnail(apr_pool_t *pool,
                                            apr_size_t item_id,
                                            void *var_memory,
-                                           void *sca_memory) const throw()
+                                           void *sca_memory) const
 {
     variable_t *thumbnail_var;
     scalar_t *thumbnail_sca;
@@ -138,7 +138,6 @@ apr_size_t ThumbnailVariableCreator::get_thumbnail_memory_size() const
  * テスト
  *****************************************************************************/
 #ifdef DEBUG_ThumbnailVariableCreator
-#include "TestRunner.h"
 #include "TemplateParser.h"
 #include "UploadItemList.h"
 #include "UploadItemListReader.h"
@@ -146,6 +145,8 @@ apr_size_t ThumbnailVariableCreator::get_thumbnail_memory_size() const
 #include "ThumbnailIterator.h"
 #include "Message.h"
 
+#include "TestRunner.h"
+
 static const apr_size_t THUMBNAIL_LIST_SIZE  = 10;
 static const apr_size_t MAX_LIST_SIZE   = 1000;
 
