@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: uploader_handler.cpp 2374 2007-01-23 13:42:21Z svn $
+ * $Id: uploader_handler.cpp 2384 2007-02-14 15:15:33Z svn $
  *****************************************************************************/
 
 #ifndef TEMPLATE_INSTANTIATION
@@ -56,11 +56,12 @@
 #include "SourceInfo.h"
 
 #ifndef TEMPLATE_INSTANTIATION
-SOURCE_INFO_ADD("$Id: uploader_handler.cpp 2374 2007-01-23 13:42:21Z svn $");
+SOURCE_INFO_ADD("$Id: uploader_handler.cpp 2384 2007-02-14 15:15:33Z svn $");
 #endif
 
-#define IS_REQUEST_COMMAND(arg, command) \
-    (strncmp(arg, command, LITERAL_STRLEN(command)) == 0)
+#define IS_REQUEST_COMMAND(arg, command)                        \
+    ((strncmp(arg, command, LITERAL_STRLEN(command)) == 0) &&    \
+     (arg[LITERAL_STRLEN(command)] == '\0'))
 
 static const apr_size_t PER_PAGE_THUMBNAIL_NUMBER = 100;
 
@@ -885,15 +886,7 @@ static int admin(typename Response::Handle *r, UploaderConfig *config,
     apr_size_t page_count;
 
     Response::set_content_type(r, PAGE_CONTENT_TYPE);
-#ifndef DEBUG
-    Response::set_modified_time(r, config->get_item_manager()->get_mtime());
-    Response::set_last_modified(r, config->get_item_manager()->get_mtime());
 
-    int status;
-    if ((status = Response::is_meets_condition(r)) != OK) {
-        return status;
-    }
-#endif
     if (Response::is_head_method(r)) {
         return OK;
     }
@@ -973,13 +966,13 @@ int uploader_command_handler(typename Response::Handle *r, UploaderConfig *confi
 
     if (UNLIKELY(*arg == '\0')) {
         request_uri = Response::get_request_uri(r);
-#ifdef DEBUG
+
         if (UNLIKELY(*(request_uri + strlen(request_uri) - 1) ==
                      ARG_SEPARATE_STR[0])) {
             return error<Response>(r, config,
                                    MESSAGE_ENVIRONMENT_LOCATION_DIR_EXIST);
         }
-#endif
+
         Response::set_location(r,
                                apr_pstrcat(r->pool, request_uri, "/", NULL));
 
